@@ -332,13 +332,13 @@ class Dao:
 
         du.lock_one_deft(rec.site_id, rec.id, self.pod.std_db_lock())
 
-        if du.rec.tm_stamp != rec.tm_stamp:
-            raise xMettle("Stale data. Please refresh and try again.", self.MODULE)
+        if du.rec.tm_stamp.replace(microsecond=0) != rec.tm_stamp.replace(microsecond=0):
+            raise xMettle("Stale data. Please refresh and try again.")
 
         bef = copy.copy(du.rec)
 
-        if bef.date_activate != datetime.date.min and bef.date_activate <= datetime.date.today():
-            rec.date_activate  = bef.date_activate
+        if bef.date_activate and bef.date_activate <= datetime.date.today():
+            rec.date_activate = bef.date_activate
 
         if not internal:
             rec.status      = bef.status
@@ -583,7 +583,7 @@ class Dao:
             usr_id,
             tUsrOtp.OtpMethod_Couplet.key_none,
             '',
-            datetime.datetime.min,
+            None,
             False,
             '',
             0,
