@@ -100,8 +100,8 @@ class DaoAsync:
         """
         Initialize a new logo trigger from the config table.
         """
-        loco_type = self.read_config(0, 'loco.trigger.type', str)
-        loco_cfg  = self.read_config(0, 'loco.trigger.cfg',  str)
+        loco_type = await self.read_config(0, 'loco.trigger.type', str)
+        loco_cfg  = await self.read_config(0, 'loco.trigger.cfg',  str)
         lcfg      = None if not loco_cfg else json.loads(loco_cfg)
 
         from bs_loco import trigger
@@ -347,12 +347,12 @@ class DaoAsync:
 
         await du.lock_one_deft(rec.site_id, rec.id, self.pod.std_db_lock())
 
-        if du.rec.tm_stamp != rec.tm_stamp:
-            raise xMettle("Stale data. Please refresh and try again.", self.MODULE)
+        if du.rec.tm_stamp.replace(microsecond=0) != rec.tm_stamp.replace(microsecond=0):
+            raise xMettle("Stale data. Please refresh and try again.")
 
         bef = copy.copy(du.rec)
 
-        if bef.date_activate != datetime.date.min and bef.date_activate <= datetime.date.today():
+        if bef.date_activate and bef.date_activate <= datetime.date.today():
             rec.date_activate  = bef.date_activate
 
         if not internal:
@@ -658,6 +658,9 @@ class DaoAsync:
         if add_tags:
             utags.update(add_tags)
 
+        if not self.loco_trig:
+            await self.initialize()
+
         await self.loco_trig.trig(loco_type, addr, utags, meta_data = meta_data)
 
 
