@@ -29,19 +29,17 @@ import copy
 import datetime
 import mettle
 import json
-import time
 
-from mettle.lib.xMettle import xMettle
+from mettle.lib import xMettle
 
 from bs_fura.braze import FuraServerInterface
 
-from .             import fura_dav_cache
+from .             import fura_davcache
 from .dao          import Dao
-from .errcode      import ErrCode
+from .err_code     import ErrCode
 from .user_login   import UserLogin
-from .web_token    import FuraToken
+from .fura_token   import FuraToken
 from .xfura        import xFura
-from .             import util
 
 from .auth           import factory as AuthFactory
 
@@ -55,6 +53,8 @@ from .db.tables   import tUsr
 from .db.tables   import tUsrAuth
 from .db.tables   import tUsrType
 
+import bs_fura
+
 from bs_fura.braze  import bAuthPolicy
 from bs_fura.braze  import bRoleFuncRel
 from bs_fura.braze  import ResetMethod_Couplet
@@ -64,8 +64,7 @@ from bs_lib.auto_transaction import AutoTransaction
 from bs_lib                  import Pod
 from bs_lib                  import query_builder
 
-from bs_triceraclops.audit  import Audit
-
+from bs_audit.audit  import Audit
 
 
 class FuraServerImpl(FuraServerInterface):
@@ -82,7 +81,7 @@ class FuraServerImpl(FuraServerInterface):
         self._shutdown = False
         self._pod      = pod
         self._log      = pod.log
-        self._dao      = Dao(self._pod, util.dao_by_name(dao_name))
+        self._dao      = Dao(self._pod, bs_fura.dao_by_name(dao_name))
         self._audit    = Audit(self._pod.dbcon, dao_name)
 
         self._fura_token = None
@@ -124,8 +123,8 @@ class FuraServerImpl(FuraServerInterface):
             return FuraToken(json.loads(fura_cfg['token.webkey']))
 
 
-    def _init_dav_cache(self, rpcName, dvc):
-        fura_dav_cache.initDavCache(dvc)
+    def _init_dav_cache(self, rpc_name, dvc):
+        fura_davcache.init_davcache(dvc)
 
 
     def _has_new_rpc_token(self):
@@ -197,14 +196,6 @@ class FuraServerImpl(FuraServerInterface):
     # ------------------------------------------------------------------------
 
 
-    def ping(self):
-        """
-        Ping method to test is server is up.
-        """
-        time.sleep(0.5)
-        return True
-
-
     def auth_policy_read(self,
                          auth_type: str,
                          site_code: str) -> bAuthPolicy:
@@ -258,7 +249,7 @@ class FuraServerImpl(FuraServerInterface):
 
             dc.lock_one_deft(rec.id, self._pod.std_db_lock())
 
-            if dc.rec.tm_stamp != rec.tm_stamp:
+            if dc.rec.tm_stamp.replace(microsecond=0) != rec.tm_stamp.replace(microsecond=0):
                 raise xMettle('Stale data. Refresh and try again.', self.MODULE)
 
             bef = copy.copy(dc.rec)
@@ -351,7 +342,7 @@ class FuraServerImpl(FuraServerInterface):
 
             rl.lock_one_deft(self._site_id(), rec.id, self._pod.std_db_lock())
 
-            if rl.rec.tm_stamp != rec.tm_stamp:
+            if rl.rec.tm_stamp.replace(microsecond=0) != rec.tm_stamp.replace(microsecond=0):
                 raise xMettle('Stale data. Refresh and try again.', self.MODULE)
 
             bef              = copy.copy(rl.rec)
@@ -534,7 +525,7 @@ class FuraServerImpl(FuraServerInterface):
 
             dsc.lock_one_deft(self._site_id(), rec.id, self._pod.std_db_lock())
 
-            if dsc.rec.tm_stamp != rec.tm_stamp:
+            if dsc.rec.tm_stamp.replace(microsecond=0) != rec.tm_stamp.replace(microsecond=0):
                 raise xMettle('Stale data. Refresh and try again.', self.MODULE)
 
             bef             = copy.copy(dsc.rec)
@@ -561,7 +552,7 @@ class FuraServerImpl(FuraServerInterface):
                     site_rec: tSite,
                     admin_email: str,
                     admin_passwd: str) -> int:
-        self._log.debug('siteCreate[%s] - start[site:%s, email:%s, passwd:***' % (
+        self._log.debug('site_create[%s] - start[site:%s, email:%s, passwd:***' % (
             self._usr_id(), str(site_rec), admin_email))
 
         with AutoTransaction(self._audit, self._pod) as at:
@@ -585,27 +576,22 @@ class FuraServerImpl(FuraServerInterface):
                            tRole.Status_Couplet.key_super_user,
                            5,
                            10,
-                           self._usr_id(),
-                           '')
+                           self._usr_id())
 
             self._audit.diff(None, rl.rec, 'fura.role')
 
             usr = self._dao.db_dao.dUsr(self._pod.dbcon)
-            usr.insert_deft(
-                site_rec.id,
-                'admin',
-                'admin',
-                tUsr.Status_Couplet.key_active,
-                '',
-                '',
-                '',
-                datetime.date.today(),
-                datetime.date.min, admin_email,
-                '',
-                '',
-                '',
-                self._usr_id(),
-                'sys')
+
+            usr.rec.site_id       = site_rec.id
+            usr.rec.id            = 'admin'
+            usr.rec.role_id       = 'admin'
+            usr.rec.status        = tUsr.Status_Couplet.key_active
+            usr.rec.date_activate = datetime.date.today()
+            usr.rec.email1        = 'admin_email'
+            usr.rec.modified_by   = self._usr_id()
+            usr.rec.usrtype_id    = 'sys'
+
+            usr.insert()
 
             self._audit.diff(None, usr.rec, 'fura.usr')
 
@@ -614,6 +600,7 @@ class FuraServerImpl(FuraServerInterface):
                                  'admin',
                                  tUsrAuth.AuthType_Couplet.key_password,
                                  admin_passwd,
+                                 None,
                                  None)
 
             dc = self._dao.db_dao.dSiteCfg(self._pod.dbcon)
@@ -631,7 +618,7 @@ class FuraServerImpl(FuraServerInterface):
 
             at.commit()
 
-        self._log.debug('siteCreate[%s] - done[site_id:%d]' % (self._usr_id(), site_rec.id))
+        self._log.debug('site_create[%s] - done[site_id:%d]' % (self._usr_id(), site_rec.id))
 
         return site_rec.id
 
@@ -641,11 +628,11 @@ class FuraServerImpl(FuraServerInterface):
             res = tSite.List()
 
             if site_code:
-                qry = self._dao.db_dao.dSiteSelectAll(self._pod.dbcon)
-                qry.exec().fetch_all(res)
-            else:
                 qry = self._dao.db_dao.dSiteByCode(self._pod.dbcon)
                 qry.exec_deft(site_code).fetch_all(res)
+            else:
+                qry = self._dao.db_dao.dSiteSelectAll(self._pod.dbcon)
+                qry.exec().fetch_all(res)
 
             return res
 
@@ -656,7 +643,7 @@ class FuraServerImpl(FuraServerInterface):
 
             ds.lock_one_deft(rec.id, self._pod.std_db_lock())
 
-            if ds.rec.tm_stamp != rec.tm_stamp:
+            if ds.rec.tm_stamp.replace(microsecond=0) != rec.tm_stamp.replace(microsecond=0):
                 raise xMettle("Stale data. Please refresh and try again.", self.MODULE)
 
             bef             = copy.copy(ds.rec)
@@ -760,13 +747,14 @@ class FuraServerImpl(FuraServerInterface):
 
             return res
 
+
     def user_login(self, ul_rec: bUserLogin) -> int:
         with AutoTransaction(self._pod) as at:
-            self._pod.usr_id = ul_rec.userId
+            self._pod.usr_id = ul_rec.user_id
 
             try:
                 with UserLogin(self._dao, ul_rec.site_code) as ul:
-                    ul.login(ul_rec.userId, ul_rec.auth_type, ul_rec.authData, ul_rec.ipAddr, ul_rec.geoLoc)
+                    ul.login(ul_rec.user_id, ul_rec.auth_type, ul_rec.auth_data, ul_rec.ip_addr, ul_rec.geo_loc)
 
                     self._new_token = ul.gen_fura_token(self._fura_token)
 
@@ -926,13 +914,13 @@ class FuraServerImpl(FuraServerInterface):
             try:
                 with UserLogin(self._dao, ul_rec.site_code, self._audit) as ul:
                     ul.set_auth_data(self._audit,
-                                     ul_rec.userId,
+                                     ul_rec.user_id,
                                      ul_rec.auth_type,
-                                     ul_rec.authData,
+                                     ul_rec.auth_data,
                                      tok,
                                      reset_method,
-                                     ul_rec.ipAddr,
-                                     ul_rec.geoLoc)
+                                     ul_rec.ip_addr,
+                                     ul_rec.geo_loc)
             finally:
                 at.commit()
 
@@ -1062,7 +1050,7 @@ class FuraServerImpl(FuraServerInterface):
 
             dut.lock_one_deft(rec.id, self._pod.std_db_lock())
 
-            if dut.rec.tm_stamp != rec.tm_stamp:
+            if dut.rec.tm_stamp.replace(microsecond=0) != rec.tm_stamp.replace(microsecond=0):
                 raise xMettle('Stale data. Refresh and try again.', self.MODULE)
 
             bef = copy.copy(dut.rec)
