@@ -409,6 +409,9 @@ from being reset manually." % (ao.auth_type_name()))
 
         self._dao.pod.usr_id = targ_usr
 
+        if not self._dao.loco_trig:
+            await self._dao.initialize()
+
         loco_cnt = await self._dao.loco_trig.trig(loco_type, addr_obj, tags, meta_data = meta_data)
 
         self._dao.pod.log.info('  - triggered %d notifications [%s]' % (loco_cnt, loco_type))
@@ -649,6 +652,9 @@ Please contact your system administrator.')
         loco_tags['contact_type'] = 'Email' if otp_method == ResetMethod_Couplet.key_email else 'Cell Number'
         loco_tags['contact_addr'] = contact_addr
 
+        if not self._dao.loco_trig:
+            self._dao.initialize()
+
         loco_cnt = await self._dao.loco_trig.trig(loco_type, addr_obj, loco_tags, meta_data = loco_meta_data)
 
         self._dao.pod.log.info('  - triggered %d notifications [%s]' % (loco_cnt, loco_type))
